# Clear Cut

This package is intended to serve as a tool to sketch out the edges of any provided image. This is a personal project which I am - to use an appropriate term - *channeling* my number crunching desire into.

Refer to [this repo](https://github.com/chrispdharman/clear-cut) if you would like to play around with the source code.
